fn handle_syscall(fp: u64)Expand description
dispatch a syscall (int 0x80). The syscall number is in rax; args in rdi, rsi, rdx. The return value is written back into the trap frame’s rax so iretq returns it to user space.
fn handle_syscall(fp: u64)dispatch a syscall (int 0x80). The syscall number is in rax; args in rdi, rsi, rdx. The return value is written back into the trap frame’s rax so iretq returns it to user space.